==> tomahawk12-1.1.14-src.tar.gz: tomahawk12-1.1.14/src/org/apache/myfaces/custom/schedule/ScheduleTagHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.custom.schedule;

import com.sun.facelets.tag.MetaRuleset;
import com.sun.facelets.tag.MethodRule;
import com.sun.facelets.tag.jsf.ComponentConfig;
import com.sun.facelets.tag.jsf.html.HtmlComponentHandler;

/**
 * 
 * @since 1.1.7
 */
public class ScheduleTagHandler extends HtmlComponentHandler {
 
    private static final String MOUSE_LISTENER = "mouseListener";
    
    private static final Class [] mouseListenerParamList = new Class[]{ScheduleMouseEvent.class}; 

    public ScheduleTagHandler(ComponentConfig tagConfig) {
        super(tagConfig);
    }

    protected MetaRuleset createMetaRuleset(Class type)
    {       
        return super.createMetaRuleset(type).addRule(
                new MethodRule(MOUSE_LISTENER, 
                        String.class, mouseListenerParamList));
    }

 }

==> tomahawk20-1.1.14-src.tar.gz: tomahawk20-1.1.14/src/org/apache/myfaces/custom/schedule/ScheduleTagHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.custom.schedule;

import javax.faces.view.facelets.ComponentConfig;
import javax.faces.view.facelets.ComponentHandler;
import javax.faces.view.facelets.MetaRuleset;

import org.apache.myfaces.custom.facelets.tag.MethodRule;

/**
 * 
 * @since 1.1.7
 */
public class ScheduleTagHandler extends ComponentHandler {
 
    private static final String MOUSE_LISTENER = "mouseListener";
    private static final String MOUSE_LISTENER_EXPRESSION = "mouseListenerExpression";
    
    private static final Class [] mouseListenerParamList = new Class[]{ScheduleMouseEvent.class}; 

    public ScheduleTagHandler(ComponentConfig tagConfig) {
        super(tagConfig);
    }

    protected MetaRuleset createMetaRuleset(Class type)
    {       
        return super.createMetaRuleset(type).alias("class", "styleClass")
            .addRule(
                new MethodRule(MOUSE_LISTENER, MOUSE_LISTENER_EXPRESSION, 
                        String.class, mouseListenerParamList));
    }

 }
